=======================
The ``atelier`` package
=======================




`atelier` is a collection of tools for managing and maintaining Python software
projects.

It contains:

- some general Python utilities
  (`atelier.utils <https://lino-framework.gitlab.io/atelier/api/atelier.utils.html>`_)
- some Sphinx extensions
  (`atelier.sphinxconf <https://lino-framework.gitlab.io/atelier/api/atelier.sphinxconf.html>`_)
- a library of invoke commands
  (`atelier.invlib <https://lino-framework.gitlab.io/atelier/api/atelier.invlib.html>`_)
- a minimalistic project management
  (`atelier.projects <https://lino-framework.gitlab.io/atelier/api/atelier.projects.html>`_)

The central project homepage is https://lino-framework.gitlab.io/atelier


